provider "alicloud" {
  region = var.region
}

// Zone
data "alicloud_zones" "default" {
  available_disk_category     = "cloud_efficiency"
  available_resource_creation = "Instance"

}
// Instance specifications：1 vCPU and 2 GiB memory.
data "alicloud_instance_types" "default" {
  availability_zone    = data.alicloud_zones.default.zones.0.id
  spot_strategy        = "SpotWithPriceLimit"
  cpu_core_count       = 1
  memory_size          = 2
}
// Image
data "alicloud_images" "default" {
  most_recent   = true
  instance_type = data.alicloud_instance_types.default.instance_types[0].id
  owners        = "system"
  name_regex    = "^aliyun_3_x64"
}

resource "alicloud_vpc" "default" {
  description = "dns-server"
  cidr_block  = "192.168.0.0/16"
  vpc_name    = "dns-server"
}

resource "alicloud_vswitch" "default" {
  vswitch_name = "dns-server"
  cidr_block   = "192.168.1.0/24"
  vpc_id       = alicloud_vpc.default.id
  zone_id      = data.alicloud_zones.default.zones.0.id
}

resource "alicloud_security_group" "default" {
  name   = "dns-server"
  vpc_id = alicloud_vpc.default.id
}

resource "alicloud_security_group_rule" "allow_all" {
  type              = "ingress"
  ip_protocol       = "all"
  nic_type          = "intranet"
  policy            = "accept"
  port_range        = "1/65535"
  priority          = 1
  security_group_id = alicloud_security_group.default.id
  cidr_ip           = "0.0.0.0/0"
}

resource "alicloud_instance" "dns" {
  security_groups         = alicloud_security_group.default.*.id
  instance_type           = data.alicloud_instance_types.default.instance_types[0].id
  image_id                = data.alicloud_images.default.images[0].id
  system_disk_category    = "cloud_efficiency"
  system_disk_name        = "dns-server"
  system_disk_description = "dns-server"
  instance_name           = "dns-server"
  vswitch_id              = alicloud_vswitch.default.id
  user_data               = file("scripts/dns-init.sh")
  private_ip              = "192.168.1.197"
  instance_charge_type    = "PostPaid"
  spot_strategy           = "SpotWithPriceLimit"
}

resource "alicloud_instance" "instance1" {
  security_groups         = alicloud_security_group.default.*.id
  instance_type           = data.alicloud_instance_types.default.instance_types[0].id
  image_id                = data.alicloud_images.default.images[0].id
  system_disk_category    = "cloud_efficiency"
  system_disk_name        = "dns-server"
  system_disk_description = "dns-server"
  instance_name           = "ecs01"
  vswitch_id              = alicloud_vswitch.default.id
  private_ip              = "192.168.1.196"
  instance_charge_type    = "PostPaid"
  spot_strategy           = "SpotWithPriceLimit"
}

resource "alicloud_instance" "instance2" {
  security_groups         = alicloud_security_group.default.*.id
  instance_type           = data.alicloud_instance_types.default.instance_types[0].id
  image_id                = data.alicloud_images.default.images[0].id
  system_disk_category    = "cloud_efficiency"
  system_disk_name        = "dns-server"
  system_disk_description = "dns-server"
  instance_name           = "ecs02"
  vswitch_id              = alicloud_vswitch.default.id
  private_ip              = "192.168.1.198"
  instance_charge_type    = "PostPaid"
  spot_strategy           = "SpotWithPriceLimit"
}

resource "alicloud_eip_address" "default" {
  description  = "dns-server"
  isp          = "BGP"
  address_name = "dns-server"
  netmode      = "public"
  bandwidth    = "1"
  payment_type = "PayAsYouGo"
}

resource "alicloud_eip_association" "default" {
  allocation_id = alicloud_eip_address.default.id
  instance_id   = alicloud_instance.dns.id
}