#!/bin/sh
yum install -y bind bind-utils

printf '
options {
        listen-on port 53 { any; };
        listen-on-v6 port 53 { ::1; };
        directory       "/var/named";
        dump-file       "/var/named/data/cache_dump.db";
        statistics-file "/var/named/data/named_stats.txt";
        memstatistics-file "/var/named/data/named_mem_stats.txt";
        secroots-file   "/var/named/data/named.secroots";
        recursing-file  "/var/named/data/named.recursing";
        allow-query     { any; };

        recursion yes;

        dnssec-enable yes;
        dnssec-validation yes;

        managed-keys-directory "/var/named/dynamic";

        pid-file "/run/named/named.pid";
        session-keyfile "/run/named/session.key";

        include "/etc/crypto-policies/back-ends/bind.config";
};

logging {
        channel default_debug {
                file "data/named.run";
                severity dynamic;
        };
};

zone "." IN {
        type hint;
        file "named.ca";
};

include "/etc/named.rfc1912.zones";

' > /etc/named.conf

printf '
zone "example.com" IN {
      type master;
      file "example.com.zone";
};

zone "1.168.192.in-addr.arpa" IN {
      type master;
      file "1.168.192.zone";
};
' > /etc/named.rfc1912.zones
cp -p /var/named/named.localhost /var/named/example.com.zone

printf '
$TTL 1D
@       IN      SOA     example.com.  admin.example.com. (
                                                           1       ; serial
                                                           1D      ; refresh
                                                           1H      ; retry
                                                           1W      ; expire
                                                           3H )    ; minimum

              NS      dns.example.com.
dns           A       192.168.1.197; 
Web01         A       192.168.1.196; 
Web02         A       192.168.1.198;
' > /var/named/example.com.zone

cp -p /var/named/named.empty /var/named/1.168.192.zone

printf '
$TTL 3H
@       IN      SOA     1.168.192.in-addr.arpa. admin.zjq.com. (
                                                           1       ; serial
                                                           1D      ; refresh
                                                           1H      ; retry
                                                           1W      ; expire
                                                           3H )    ; minimum

              NS      dns.example.com.
197           PTR     dns.example.com.
196           PTR     Web01.example.com.
198           PTR     Web02.example.com.
' > /var/named/1.168.192.zone

printf '
nameserver  192.168.1.197
' > /etc/resolv.conf

systemctl restart named
